yagocd package
==============

Subpackages
-----------

.. toctree::

    yagocd.resources

Submodules
----------

yagocd.client module
--------------------

.. automodule:: yagocd.client
    :members:
    :undoc-members:
    :show-inheritance:

yagocd.session module
---------------------

.. automodule:: yagocd.session
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: yagocd
    :members:
    :undoc-members:
    :show-inheritance:
